@@ -9,30 +9,6 @@ from html_rewriter import HTMLRewriter
 import itertools
 
 HTML = HTMLRewriter
-_is_lxml = False
-
-
-#=================================================================
-def use_lxml_parser():
-    import logging
-    from lxml_html_rewriter import LXMLHTMLRewriter, LXML_SUPPORTED
-
-    if LXML_SUPPORTED:
-        global HTML
-        global _is_lxml
-        HTML = LXMLHTMLRewriter
-        logging.debug('Using LXML Parser')
-        _is_lxml = True
-    else:  # pragma: no cover
-        logging.debug('LXML Parser not available')
-        _is_lxml = False
-
-    return _is_lxml
-
-
-#=================================================================
-def is_lxml():
-    return _is_lxml
 
 
 #=================================================================
